@@ -2,11 +2,13 @@ import uuid
 import requests
 import json
 import enum
+import zipfile
+import os
 
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
-API_GW = "https://5uetvct10a.execute-api.us-east-1.amazonaws.com/api"
+API_GW = "https://86iu7tieha.execute-api.us-east-2.amazonaws.com/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -20,8 +22,9 @@ class FileType(enum.Enum):
     Test = 2
     EntryPoint = 3
     Code = 4
+    Inputs = 5
 
-def create_training_job(local_train_data, local_test_data, entry_point, code_folder, hyper_param:dict):
+def create_training_job(local_train_data, local_test_data, entry_point, inputs_folder, hyper_param:dict):
 
     # create job id
 
@@ -31,8 +34,8 @@ def create_training_job(local_train_data, local_test_data, entry_point, code_fol
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
     if local_train_data is not None:
-        __upload_one_file(job_id, FileType.Train.name, local_test_data)
-        print(f"upladed {local_test_data}")
+        __upload_one_file(job_id, FileType.Train.name, local_train_data)
+        print(f"upladed {local_train_data}")
 
     if local_test_data is not None:
         __upload_one_file(job_id, FileType.Test.name, local_test_data)
@@ -42,10 +45,12 @@ def create_training_job(local_train_data, local_test_data, entry_point, code_fol
         __upload_one_file(job_id, FileType.EntryPoint.name, entry_point)
         print(f"upladed {entry_point}")
 
-    if code_folder is not None:
+    if inputs_folder is not None:
         ## TODO Zip the files on the folder and upload all.
-        # __upload_one_file(job_id, FileType.Code.name, )
-        print(f"upladed {code_folder}")
+        #get_zipfile(inputs_folder,'./mnist')
+
+        __upload_one_file(job_id, FileType.Inputs.name, inputs_folder)
+        print(f"upladed {inputs_folder}")
         pass
 
     # put hyper param to Dynamodb through API Gateway
@@ -73,6 +78,21 @@ def cancel_training_job_status(job_id):
     """
     pass
 
+def get_zipfile(dirpath,outpath):
+	"""
+	zip file
+	:dirpath: source
+	:outpath: dest
+	"""
+
+	zip = zipfile.ZipFile(outpath, "w", zipfile.ZIP_DEFLATED)
+	for path, dirnames, filenames in os.walk(dirpath):
+		fpath = path.replace(dirpath, '')
+		for filename in filenames:
+			zip.write(os.path.join(path, filename), os.path.join(fpath,filename))
+	zip.close()
+
+
 ##############################################
 # Helpers
 ##############################################
